@@ -24,20 +24,23 @@ def parse_to_CGP_object(python_object):
 
 def parse_to_python_object(string, from_CLI=True):
     def preparse_from_CLI(string):
-        string = string.replace('\n', '')  
+        return string.replace('\n', '')  
     
     def parse_array(string):
         result_arr = list()
         values = string[1:-1]
         
         pos = values.find(',')
-        el = values
         
         while pos != -1:            
             el = values[:pos]
             while el.count('"')%2 != 0:
                 pos = values.find(',', pos+1)
-                el = values[:values.find(',', pos+1)]
+                if pos == -1:
+                    el = values[:]
+                    values = ''
+                else:
+                    el = values[:pos]
     
             while el.count('(') != el.count(')'):
                 pos = values.find(')', pos+1)
@@ -87,7 +90,7 @@ def parse_to_python_object(string, from_CLI=True):
     string.strip()
     
     if from_CLI:
-        preparse_from_CLI(string)
+        string = preparse_from_CLI(string)
         
     #if dict
     if string[0] == '{':
